=== modified file 'drizzled/alter_info.h'
--- drizzled/alter_info.h	2011-02-17 00:14:13 +0000
+++ drizzled/alter_info.h	2011-03-01 12:43:56 +0000
@@ -25,21 +25,19 @@
 #ifndef DRIZZLED_ALTER_INFO_H
 #define DRIZZLED_ALTER_INFO_H
 
+#include <drizzled/alter_column.h>
+#include <drizzled/alter_drop.h>
 #include <drizzled/base.h>
 #include <drizzled/enum.h>
-#include <drizzled/sql_list.h> /** @TODO use STL vectors! */
 #include <drizzled/key.h>
 #include <drizzled/message/table.pb.h>
 
 #include <bitset>
-
-namespace drizzled
-{
-
-/* Some forward declarations needed */
+#include <list>
+
+namespace drizzled {
+
 class CreateField;
-class AlterDrop;
-class AlterColumn;
 
 enum enum_alter_info_flags
 {
@@ -81,8 +79,11 @@
 class AlterInfo
 {
 public:
-  List<AlterDrop> drop_list;
-  List<AlterColumn> alter_list;
+  typedef std::list<AlterDrop> drop_list_t;
+  typedef std::list<AlterColumn> alter_list_t;
+  
+  drop_list_t drop_list;
+  alter_list_t alter_list;
   List<Key> key_list;
   List<CreateField> create_list;
   message::AlterTable alter_proto;

=== modified file 'drizzled/dynamic_array.cc'
--- drizzled/dynamic_array.cc	2011-02-17 00:14:13 +0000
+++ drizzled/dynamic_array.cc	2011-03-01 18:51:28 +0000
@@ -93,21 +93,22 @@
     false	Ok
 */
 
-bool insert_dynamic(DYNAMIC_ARRAY *array, unsigned char* element)
+static void insert_dynamic(DYNAMIC_ARRAY *array, void* element)
 {
   unsigned char* buffer;
   if (array->elements == array->max_element)
-  {						/* Call only when nessesary */
-    if (!(buffer=alloc_dynamic(array)))
-      return true;
-  }
+    buffer= alloc_dynamic(array);
   else
   {
-    buffer=array->buffer+(array->elements * array->size_of_element);
+    buffer= array->buffer+(array->elements * array->size_of_element);
     array->elements++;
   }
-  memcpy(buffer,element,(size_t) array->size_of_element);
-  return false;
+  memcpy(buffer,element, array->size_of_element);
+}
+
+void DYNAMIC_ARRAY::push_back(void* v)
+{
+  insert_dynamic(this, v);
 }
 
 

=== modified file 'drizzled/dynamic_array.h'
--- drizzled/dynamic_array.h	2011-02-23 13:15:31 +0000
+++ drizzled/dynamic_array.h	2011-03-01 19:15:55 +0000
@@ -21,48 +21,41 @@
 #ifndef DRIZZLED_DYNAMIC_ARRAY_H
 #define DRIZZLED_DYNAMIC_ARRAY_H
 
-#include <stddef.h>
-
-namespace drizzled
-{
-
-typedef struct st_dynamic_array
-{
+#include <cstddef>
+
+namespace drizzled {
+
+class DYNAMIC_ARRAY
+{
+public:
   unsigned char *buffer;
   size_t elements;
   size_t max_element;
   uint32_t alloc_increment;
   uint32_t size_of_element;
 
+  void push_back(void*);
+
   size_t size() const
   {
     return elements;
   }
-} DYNAMIC_ARRAY;
+};
 
 #define my_init_dynamic_array(A,B,C,D) init_dynamic_array2(A,B,NULL,C,D)
 #define my_init_dynamic_array_ci(A,B,C,D) init_dynamic_array2(A,B,NULL,C,D)
 
-extern bool init_dynamic_array2(DYNAMIC_ARRAY *array,uint32_t element_size,
+bool init_dynamic_array2(DYNAMIC_ARRAY *array,uint32_t element_size,
                                    void *init_buffer, uint32_t init_alloc,
                                    uint32_t alloc_increment);
 /* init_dynamic_array() function is deprecated */
-extern bool init_dynamic_array(DYNAMIC_ARRAY *array,uint32_t element_size,
+bool init_dynamic_array(DYNAMIC_ARRAY *array,uint32_t element_size,
                                   uint32_t init_alloc,uint32_t alloc_increment);
-extern bool insert_dynamic(DYNAMIC_ARRAY *array,unsigned char * element);
-extern unsigned char *alloc_dynamic(DYNAMIC_ARRAY *array);
-extern unsigned char *pop_dynamic(DYNAMIC_ARRAY*);
-extern bool set_dynamic(DYNAMIC_ARRAY *array,unsigned char * element,uint32_t array_index);
-extern void get_dynamic(DYNAMIC_ARRAY *array,unsigned char * element,uint32_t array_index);
-extern void delete_dynamic(DYNAMIC_ARRAY *array);
-extern void delete_dynamic_element(DYNAMIC_ARRAY *array, uint32_t array_index);
-extern void freeze_size(DYNAMIC_ARRAY *array);
-extern int  get_index_dynamic(DYNAMIC_ARRAY *array, unsigned char * element);
-#define dynamic_array_ptr(array,array_index) ((array)->buffer+(array_index)*(array)->size_of_element)
-#define dynamic_element(array,array_index,type) ((type)((array)->buffer) +(array_index))
-#define push_dynamic(A,B) insert_dynamic((A),(B))
-#define reset_dynamic(array) ((array)->elements= 0)
-#define sort_dynamic(A,cmp) my_qsort((A)->buffer, (A)->elements, (A)->size_of_element, (cmp))
+unsigned char *alloc_dynamic(DYNAMIC_ARRAY *array);
+unsigned char *pop_dynamic(DYNAMIC_ARRAY*);
+bool set_dynamic(DYNAMIC_ARRAY *array,unsigned char * element,uint32_t array_index);
+void get_dynamic(DYNAMIC_ARRAY *array,unsigned char * element,uint32_t array_index);
+void delete_dynamic(DYNAMIC_ARRAY *array);
 
 } /* namespace drizzled */
 

=== modified file 'drizzled/internal/default.cc' (properties changed: +x to -x)
--- drizzled/internal/default.cc	2011-02-17 00:14:13 +0000
+++ drizzled/internal/default.cc	2011-03-01 18:51:28 +0000
@@ -292,8 +292,7 @@
   {
     if (!(tmp= (char *)ctx->alloc->alloc_root(strlen(option) + 1)))
       return 1;
-    if (insert_dynamic(ctx->args, (unsigned char*) &tmp))
-      return 1;
+    ctx->args->push_back(&tmp);
     strcpy(tmp, option);
   }
 

=== modified file 'drizzled/message/statement_transform.cc'
--- drizzled/message/statement_transform.cc	2011-02-22 21:46:00 +0000
+++ drizzled/message/statement_transform.cc	2011-03-01 19:35:29 +0000
@@ -339,6 +339,16 @@
     }
     break;
   case Statement::RAW_SQL:
+    {
+      if (source.has_raw_sql_schema())
+      {
+        string destination("USE ");
+        destination.append(source.raw_sql_schema());
+        sql_strings.push_back(destination);
+      }
+      sql_strings.push_back(source.sql());
+    }
+    break;
   default:
     sql_strings.push_back(source.sql());
     break;

=== modified file 'drizzled/message/transaction.proto'
--- drizzled/message/transaction.proto	2011-01-11 14:22:54 +0000
+++ drizzled/message/transaction.proto	2011-03-01 18:21:39 +0000
@@ -576,6 +576,8 @@
   optional AlterTableStatement alter_table_statement = 16;
   optional DropTableStatement drop_table_statement = 17;  
   optional SetVariableStatement set_variable_statement = 18;
+
+  optional string raw_sql_schema = 19;
 }
 
 /*

=== modified file 'drizzled/my_hash.cc'
--- drizzled/my_hash.cc	2011-02-17 00:14:13 +0000
+++ drizzled/my_hash.cc	2011-03-01 18:51:28 +0000
@@ -58,6 +58,8 @@
   return nr1;
 }
 
+#define dynamic_element(array,array_index,type) ((type)((array)->buffer) +(array_index))
+
 bool
 _hash_init(HASH *hash,uint32_t growth_size, const CHARSET_INFO * const charset,
            uint32_t size, size_t key_offset, size_t key_length,

=== modified file 'drizzled/optimizer/key_field.cc'
--- drizzled/optimizer/key_field.cc	2011-02-24 19:13:33 +0000
+++ drizzled/optimizer/key_field.cc	2011-03-01 18:51:28 +0000
@@ -65,7 +65,7 @@
                                    0,
                                    key_field->rejectNullValues(),
                                    key_field->getConditionalGuard());
-          insert_dynamic(keyuse_array, (unsigned char*) &keyuse);
+          keyuse_array->push_back(&keyuse);
         }
       }
     }

=== modified file 'drizzled/optimizer/quick_range_select.cc'
--- drizzled/optimizer/quick_range_select.cc	2011-02-24 18:16:42 +0000
+++ drizzled/optimizer/quick_range_select.cc	2011-03-01 17:16:41 +0000
@@ -356,7 +356,7 @@
 
   while (min != max)
   {
-    if (cmp_next(*(optimizer::QuickRange**)dynamic_array_ptr(&ranges, mid)))
+    if (cmp_next(reinterpret_cast<optimizer::QuickRange**>(ranges.buffer)[mid]))
     {
       /* current row value > mid->max */
       min= mid + 1;
@@ -365,8 +365,8 @@
       max= mid;
     mid= (min + max) / 2;
   }
-  res= *(optimizer::QuickRange**)dynamic_array_ptr(&ranges, mid);
-  return (! cmp_next(res) && ! cmp_prev(res));
+  res= reinterpret_cast<optimizer::QuickRange**>(ranges.buffer)[mid];
+  return not cmp_next(res) && not cmp_prev(res);
 }
 
 

=== modified file 'drizzled/optimizer/range.cc'
--- drizzled/optimizer/range.cc	2011-02-24 18:16:42 +0000
+++ drizzled/optimizer/range.cc	2011-03-01 18:51:28 +0000
@@ -4169,10 +4169,7 @@
   set_if_bigger(quick->max_used_key_length, (uint32_t)range->min_length);
   set_if_bigger(quick->max_used_key_length, (uint32_t)range->max_length);
   set_if_bigger(quick->used_key_parts, (uint32_t) key_tree->part+1);
-  if (insert_dynamic(&quick->ranges, (unsigned char*) &range))
-  {
-    return 1;
-  }
+  quick->ranges.push_back(&range);
 
  end:
   if (key_tree->right != &optimizer::null_element)
@@ -4296,8 +4293,7 @@
     key_part->null_bit=     key_info->key_part[part].null_bit;
     key_part->flag=         (uint8_t) key_info->key_part[part].key_part_flag;
   }
-  if (insert_dynamic(&quick->ranges,(unsigned char*)&range))
-    goto err;
+  quick->ranges.push_back(&range);
 
   /*
      Add a NULL range if REF_OR_NULL optimization is used.
@@ -4317,8 +4313,7 @@
                                  make_prev_keypart_map(ref->key_parts), EQ_RANGE)))
       goto err;
     *ref->null_ref_key= 0;		// Clear null byte
-    if (insert_dynamic(&quick->ranges,(unsigned char*)&null_range))
-      goto err;
+    quick->ranges.push_back(&null_range);
   }
 
   /* Call multi_range_read_info() to get the MRR flags and buffer size */

=== modified file 'drizzled/parser.cc'
--- drizzled/parser.cc	2011-02-27 02:20:23 +0000
+++ drizzled/parser.cc	2011-03-01 11:40:52 +0000
@@ -658,11 +658,11 @@
   if (is_foreign_key)
   {
     statement->alter_info.flags.set(ALTER_FOREIGN_KEY);
-    statement->alter_info.drop_list.push_back(new AlterDrop(AlterDrop::FOREIGN_KEY, name));
+    statement->alter_info.drop_list.push_back(AlterDrop(AlterDrop::FOREIGN_KEY, name));
   }
   else
   {
-    statement->alter_info.drop_list.push_back(new AlterDrop(AlterDrop::KEY, name));
+    statement->alter_info.drop_list.push_back(AlterDrop(AlterDrop::KEY, name));
   }
 }
 

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2011-02-28 21:18:08 +0000
+++ drizzled/sql_select.cc	2011-03-01 18:51:28 +0000
@@ -647,9 +647,9 @@
                        (qsort_cmp) sort_keyuse);
 
     memset(&key_end, 0, sizeof(key_end)); /* Add for easy testing */
-    insert_dynamic(keyuse,(unsigned char*) &key_end);
+    keyuse->push_back(&key_end);
 
-    use= save_pos= dynamic_element(keyuse, 0, optimizer::KeyUse*);
+    use= save_pos= (optimizer::KeyUse*)keyuse->buffer;
     prev= &key_end;
     found_eq_constant= 0;
     {
@@ -694,11 +694,8 @@
 */
 void optimize_keyuse(Join *join, DYNAMIC_ARRAY *keyuse_array)
 {
-  optimizer::KeyUse *end,*keyuse= dynamic_element(keyuse_array, 
-                                                  0, 
-                                                  optimizer::KeyUse*);
-
-  for (end= keyuse+ keyuse_array->size() ; keyuse < end ; keyuse++)
+  optimizer::KeyUse* keyuse= (optimizer::KeyUse*)keyuse_array->buffer;
+  for (optimizer::KeyUse* end= keyuse+ keyuse_array->size() ; keyuse < end ; keyuse++)
   {
     table_map map;
     /*

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2011-02-27 02:20:23 +0000
+++ drizzled/sql_yacc.yy	2011-03-01 11:40:52 +0000
@@ -1896,7 +1896,7 @@
           {
             statement::AlterTable *statement= (statement::AlterTable *)Lex->statement;
 
-            statement->alter_info.drop_list.push_back(new AlterDrop(AlterDrop::COLUMN, $3.str));
+            statement->alter_info.drop_list.push_back(AlterDrop(AlterDrop::COLUMN, $3.str));
             statement->alter_info.flags.set(ALTER_DROP_COLUMN);
           }
         | DROP FOREIGN KEY_SYM opt_ident
@@ -1929,14 +1929,14 @@
           {
             statement::AlterTable *statement= (statement::AlterTable *)Lex->statement;
 
-            statement->alter_info.alter_list.push_back(new AlterColumn($3.str,$6));
+            statement->alter_info.alter_list.push_back(AlterColumn($3.str,$6));
             statement->alter_info.flags.set(ALTER_COLUMN_DEFAULT);
           }
         | ALTER_SYM opt_column field_ident DROP DEFAULT
           {
             statement::AlterTable *statement= (statement::AlterTable *)Lex->statement;
 
-            statement->alter_info.alter_list.push_back(new AlterColumn($3.str, (Item*) 0));
+            statement->alter_info.alter_list.push_back(AlterColumn($3.str, (Item*) 0));
             statement->alter_info.flags.set(ALTER_COLUMN_DEFAULT);
           }
         | RENAME opt_to table_ident
@@ -4150,7 +4150,7 @@
             Lex->statement= statement;
             statement->alter_info.flags.set(ALTER_DROP_INDEX);
             statement->alter_info.build_method= $2;
-            statement->alter_info.drop_list.push_back(new AlterDrop(AlterDrop::KEY, $4.str));
+            statement->alter_info.drop_list.push_back(AlterDrop(AlterDrop::KEY, $4.str));
             if (not Lex->current_select->add_table_to_list(Lex->session, $6, NULL,
                                                           TL_OPTION_UPDATING))
               DRIZZLE_YYABORT;

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2011-02-24 19:58:57 +0000
+++ drizzled/statement/alter_table.cc	2011-03-02 15:40:48 +0000
@@ -249,24 +249,10 @@
                                 message::Table &table_message,
                                 AlterInfo *alter_info)
 {
-  /* New column definitions are added here */
-  List<CreateField> new_create_list;
-  /* New key definitions are added here */
-  List<Key> new_key_list;
-  List<AlterDrop>::iterator drop_it(alter_info->drop_list.begin());
-  List<CreateField>::iterator def_it(alter_info->create_list.begin());
-  List<AlterColumn>::iterator alter_it(alter_info->alter_list.begin());
-  List<Key>::iterator key_it(alter_info->key_list.begin());
-  List<CreateField>::iterator find_it(new_create_list.begin());
-  List<CreateField>::iterator field_it(new_create_list.begin());
-  List<Key_part_spec> key_parts;
   uint32_t used_fields= create_info->used_fields;
-  KeyInfo *key_info= table->key_info;
-  bool rc= true;
 
   /* Let new create options override the old ones */
-  message::Table::TableOptions *table_options;
-  table_options= table_message.mutable_options();
+  message::Table::TableOptions *table_options= table_message.mutable_options();
 
   if (not (used_fields & HA_CREATE_USED_DEFAULT_CHARSET))
     create_info->default_table_charset= table->getShare()->table_charset;
@@ -281,23 +267,23 @@
   }
 
   table->restoreRecordAsDefault(); /* Empty record for DEFAULT */
-  CreateField *def;
 
+  List<CreateField> new_create_list;
+  List<Key> new_key_list;
   /* First collect all fields from table which isn't in drop_list */
   Field *field;
   for (Field **f_ptr= table->getFields(); (field= *f_ptr); f_ptr++)
   {
     /* Check if field should be dropped */
-    AlterDrop *drop;
-    drop_it= alter_info->drop_list.begin();
-    while ((drop= drop_it++))
+    AlterInfo::drop_list_t::iterator drop(alter_info->drop_list.begin());
+    for (; drop != alter_info->drop_list.end(); drop++)
     {
       if (drop->type == AlterDrop::COLUMN &&
           ! my_strcasecmp(system_charset_info, field->field_name, drop->name))
       {
         /* Reset auto_increment value if it was dropped */
         if (MTYP_TYPENR(field->unireg_check) == Field::NEXT_NUMBER &&
-            ! (used_fields & HA_CREATE_USED_AUTO))
+            not (used_fields & HA_CREATE_USED_AUTO))
         {
           create_info->auto_increment_value= 0;
           create_info->used_fields|= HA_CREATE_USED_AUTO;
@@ -306,17 +292,18 @@
       }
     }
 
-    if (drop)
+    if (drop != alter_info->drop_list.end())
     {
-      drop_it.remove();
+      alter_info->drop_list.erase(drop);
       continue;
     }
     
     /* Mark that we will read the field */
     field->setReadSet();
 
+    CreateField *def;
     /* Check if field is changed */
-    def_it= alter_info->create_list.begin();
+    List<CreateField>::iterator def_it= alter_info->create_list.begin();
     while ((def= def_it++))
     {
       if (def->change &&
@@ -342,16 +329,15 @@
       */
       def= new CreateField(field, field);
       new_create_list.push_back(def);
-      alter_it= alter_info->alter_list.begin(); /* Change default if ALTER */
-      AlterColumn *alter;
+      AlterInfo::alter_list_t::iterator alter(alter_info->alter_list.begin());
 
-      while ((alter= alter_it++))
+      for (; alter != alter_info->alter_list.end(); alter++)
       {
-        if (! my_strcasecmp(system_charset_info,field->field_name, alter->name))
+        if (not my_strcasecmp(system_charset_info,field->field_name, alter->name))
           break;
       }
 
-      if (alter)
+      if (alter != alter_info->alter_list.end())
       {
         if (def->sql_type == DRIZZLE_TYPE_BLOB)
         {
@@ -368,12 +354,13 @@
         {
           def->flags|= NO_DEFAULT_VALUE_FLAG;
         }
-        alter_it.remove();
+        alter_info->alter_list.erase(alter);
       }
     }
   }
 
-  def_it= alter_info->create_list.begin();
+  CreateField *def;
+  List<CreateField>::iterator def_it= alter_info->create_list.begin();
   while ((def= def_it++)) /* Add new columns */
   {
     if (def->change && ! def->field)
@@ -399,7 +386,7 @@
     else
     {
       CreateField *find;
-      find_it= new_create_list.begin();
+      List<CreateField>::iterator find_it= new_create_list.begin();
 
       while ((find= find_it++)) /* Add new columns */
       {
@@ -430,25 +417,19 @@
         my_error(*session->getQueryString(), ER_NOT_SUPPORTED_YET);
         return true;
       }
-
       alter_info->build_method= HA_BUILD_OFFLINE;
     }
   }
 
-  if (alter_info->alter_list.size())
+  if (not alter_info->alter_list.empty())
   {
-    my_error(ER_BAD_FIELD_ERROR,
-             MYF(0),
-             alter_info->alter_list.front().name,
-             table->getMutableShare()->getTableName());
+    my_error(ER_BAD_FIELD_ERROR, MYF(0), alter_info->alter_list.front().name, table->getMutableShare()->getTableName());
     return true;
   }
 
-  if (not new_create_list.size())
+  if (new_create_list.is_empty())
   {
-    my_message(ER_CANT_REMOVE_ALL_FIELDS,
-               ER(ER_CANT_REMOVE_ALL_FIELDS),
-               MYF(0));
+    my_message(ER_CANT_REMOVE_ALL_FIELDS, ER(ER_CANT_REMOVE_ALL_FIELDS), MYF(0));
     return true;
   }
 
@@ -456,27 +437,26 @@
     Collect all keys which isn't in drop list. Add only those
     for which some fields exists.
   */
+  KeyInfo *key_info= table->key_info;
   for (uint32_t i= 0; i < table->getShare()->sizeKeys(); i++, key_info++)
   {
     char *key_name= key_info->name;
-    AlterDrop *drop;
-
-    drop_it= alter_info->drop_list.begin();
-    while ((drop= drop_it++))
+    AlterInfo::drop_list_t::iterator drop(alter_info->drop_list.begin());
+    for (; drop != alter_info->drop_list.end(); drop++)
     {
       if (drop->type == AlterDrop::KEY &&
-          ! my_strcasecmp(system_charset_info, key_name, drop->name))
+          not my_strcasecmp(system_charset_info, key_name, drop->name))
         break;
     }
 
-    if (drop)
+    if (drop != alter_info->drop_list.end())
     {
-      drop_it.remove();
+      alter_info->drop_list.erase(drop);
       continue;
     }
 
     KeyPartInfo *key_part= key_info->key_part;
-    key_parts.clear();
+    List<Key_part_spec> key_parts;
     for (uint32_t j= 0; j < key_info->key_parts; j++, key_part++)
     {
       if (! key_part->field)
@@ -484,7 +464,7 @@
 
       const char *key_part_name= key_part->field->field_name;
       CreateField *cfield;
-      field_it= new_create_list.begin();
+      List<CreateField>::iterator field_it= new_create_list.begin();
       while ((cfield= field_it++))
       {
         if (cfield->change)
@@ -565,19 +545,18 @@
   /* Copy over existing foreign keys */
   for (int32_t j= 0; j < original_proto.fk_constraint_size(); j++)
   {
-    AlterDrop *drop;
-    drop_it= alter_info->drop_list.begin();
-    while ((drop= drop_it++))
+    AlterInfo::drop_list_t::iterator drop(alter_info->drop_list.begin());
+    for (; drop != alter_info->drop_list.end(); drop++)
     {
       if (drop->type == AlterDrop::FOREIGN_KEY &&
-          ! my_strcasecmp(system_charset_info, original_proto.fk_constraint(j).name().c_str(), drop->name))
+          not my_strcasecmp(system_charset_info, original_proto.fk_constraint(j).name().c_str(), drop->name))
       {
         break;
       }
     }
-    if (drop)
+    if (drop != alter_info->drop_list.end())
     {
-      drop_it.remove();
+      alter_info->drop_list.erase(drop);
       continue;
     }
 
@@ -587,6 +566,7 @@
 
   {
     Key *key;
+    List<Key>::iterator key_it(alter_info->key_list.begin());
     while ((key= key_it++)) /* Add new keys */
     {
       if (key->type == Key::FOREIGN_KEY)
@@ -637,7 +617,7 @@
     }
   }
 
-  if (alter_info->drop_list.size())
+  if (not alter_info->drop_list.empty())
   {
     my_error(ER_CANT_DROP_FIELD_OR_KEY,
              MYF(0),
@@ -645,7 +625,7 @@
     return true;
   }
 
-  if (alter_info->alter_list.size())
+  if (not alter_info->alter_list.empty())
   {
     my_error(ER_CANT_DROP_FIELD_OR_KEY,
              MYF(0),
@@ -668,7 +648,6 @@
   table_message.set_version(table->getShare()->getTableMessage()->version());
   table_message.set_uuid(table->getShare()->getTableMessage()->uuid());
 
-  rc= false;
   alter_info->create_list.swap(new_create_list);
   alter_info->key_list.swap(new_key_list);
 
@@ -701,13 +680,8 @@
 }
 
 /* table_list should contain just one table */
-static int discard_or_import_tablespace(Session *session,
-                                              TableList *table_list,
-                                              enum tablespace_op_type tablespace_op)
+static int discard_or_import_tablespace(Session *session, TableList *table_list, tablespace_op_type tablespace_op)
 {
-  Table *table;
-  bool discard;
-
   /*
     Note that DISCARD/IMPORT TABLESPACE always is the only operation in an
     ALTER Table
@@ -715,14 +689,13 @@
   TransactionServices &transaction_services= TransactionServices::singleton();
   session->set_proc_info("discard_or_import_tablespace");
 
-  discard= test(tablespace_op == DISCARD_TABLESPACE);
-
  /*
    We set this flag so that ha_innobase::open and ::external_lock() do
    not complain when we lock the table
  */
   session->setDoingTablespaceOperation(true);
-  if (not (table= session->openTableLock(table_list, TL_WRITE)))
+  Table* table= session->openTableLock(table_list, TL_WRITE);
+  if (not table)
   {
     session->setDoingTablespaceOperation(false);
     return -1;
@@ -730,7 +703,7 @@
 
   int error;
   do {
-    error= table->cursor->ha_discard_or_import_tablespace(discard);
+    error= table->cursor->ha_discard_or_import_tablespace(tablespace_op == DISCARD_TABLESPACE);
 
     session->set_proc_info("end");
 
@@ -745,7 +718,9 @@
     if (error)
       break;
 
-    write_bin_log(session, *session->getQueryString());
+    transaction_services.rawStatement(*session,
+                                      *session->getQueryString(),
+                                      *session->schema());
 
   } while(0);
 
@@ -1074,7 +1049,9 @@
       {
         TransactionServices &transaction_services= TransactionServices::singleton();
         transaction_services.allocateNewTransactionId();
-        write_bin_log(session, *session->getQueryString());
+        transaction_services.rawStatement(*session,
+                                          *session->getQueryString(),
+                                          *session->schema());        
         session->my_ok();
       }
       else if (error > EE_OK) // If we have already set the error, we pass along -1
@@ -1341,7 +1318,10 @@
 
     session->set_proc_info("end");
 
-    write_bin_log(session, *session->getQueryString());
+    TransactionServices &transaction_services= TransactionServices::singleton();
+    transaction_services.rawStatement(*session,
+                                      *session->getQueryString(),
+                                      *session->schema());        
     table_list->table= NULL;
   }
 
@@ -1486,11 +1466,10 @@
   to->cursor->ha_start_bulk_insert(from->cursor->stats.records);
 
   List<CreateField>::iterator it(create.begin());
-  CreateField *def;
   copy_end= copy;
   for (Field **ptr= to->getFields(); *ptr ; ptr++)
   {
-    def=it++;
+    CreateField* def=it++;
     if (def->field)
     {
       if (*ptr == to->next_number_field)
@@ -1660,8 +1639,6 @@
 
 static Table *open_alter_table(Session *session, Table *table, identifier::Table &identifier)
 {
-  Table *new_table;
-
   /* Open the table so we need to copy the data to it. */
   if (table->getShare()->getType())
   {
@@ -1671,15 +1648,13 @@
     tbl.setTableName(const_cast<char *>(identifier.getTableName().c_str()));
 
     /* Table is in session->temporary_tables */
-    new_table= session->openTable(&tbl, (bool*) 0, DRIZZLE_LOCK_IGNORE_FLUSH);
+    return session->openTable(&tbl, (bool*) 0, DRIZZLE_LOCK_IGNORE_FLUSH);
   }
   else
   {
     /* Open our intermediate table */
-    new_table= session->open_temporary_table(identifier, false);
+    return session->open_temporary_table(identifier, false);
   }
-
-  return new_table;
 }
 
 } /* namespace drizzled */

=== modified file 'drizzled/statement/rename_table.cc'
--- drizzled/statement/rename_table.cc	2011-02-21 18:33:47 +0000
+++ drizzled/statement/rename_table.cc	2011-03-01 20:53:48 +0000
@@ -23,9 +23,9 @@
 #include <drizzled/lock.h>
 #include <drizzled/session.h>
 #include <drizzled/statement/rename_table.h>
-#include <drizzled/sql_table.h>
 #include <drizzled/pthread_globals.h>
 #include <drizzled/plugin/storage_engine.h>
+#include <drizzled/transaction_services.h>
 
 namespace drizzled
 {
@@ -116,7 +116,10 @@
   /* Lets hope this doesn't fail as the result will be messy */
   if (not error)
   {
-    write_bin_log(getSession(), *getSession()->getQueryString());
+    TransactionServices &transaction_services= TransactionServices::singleton();
+    transaction_services.rawStatement(*getSession(),
+                                      *getSession()->getQueryString(),
+                                      *getSession()->schema());        
     getSession()->my_ok();
   }
 

=== modified file 'drizzled/transaction_services.cc'
--- drizzled/transaction_services.cc	2011-02-22 04:19:44 +0000
+++ drizzled/transaction_services.cc	2011-03-01 19:35:29 +0000
@@ -2123,7 +2123,8 @@
 }
 
 void TransactionServices::rawStatement(Session::reference session,
-                                       const string &query)
+                                       const string &query,
+                                       const string &schema)
 {
   ReplicationServices &replication_services= ReplicationServices::singleton();
   if (! replication_services.isActive())
@@ -2134,6 +2135,8 @@
 
   initStatementMessage(*statement, message::Statement::RAW_SQL, session);
   statement->set_sql(query);
+  if (not schema.empty())
+    statement->set_raw_sql_schema(schema);
   finalizeStatementMessage(*statement, session);
 
   finalizeTransactionMessage(*transaction, session);

=== modified file 'drizzled/transaction_services.h'
--- drizzled/transaction_services.h	2011-02-17 10:09:00 +0000
+++ drizzled/transaction_services.h	2011-03-01 18:21:39 +0000
@@ -205,8 +205,16 @@
    *
    * @param session Session object which issued the statement
    * @param query Query string
+   * @param schema Schema for the table affected by the raw SQL.
    */
-  void rawStatement(Session::reference session, const std::string &query);
+  void rawStatement(Session::reference session,
+                    const std::string &query,
+                    const std::string &schema);
+
+  void rawStatement(Session::reference session, const std::string &query)
+  {
+    rawStatement(session, query, "");
+  }
 
   /* transactions: interface to plugin::StorageEngine functions */
   int rollbackTransaction(Session::reference session, bool all);

=== modified file 'drizzled/util/test.h'
--- drizzled/util/test.h	2010-12-18 04:43:40 +0000
+++ drizzled/util/test.h	2011-03-01 14:00:49 +0000
@@ -21,28 +21,20 @@
 #ifndef DRIZZLED_UTIL_TEST_H
 #define DRIZZLED_UTIL_TEST_H
 
-#if defined(__cplusplus)
-
-namespace drizzled
-{
+namespace drizzled {
 
 template <class T>
-inline bool test(const T a)
+bool test(const T a)
 {
-  return a ? true : false;
+  return a;
 }
 
 template <class T, class U>
-inline bool test_all_bits(const T a, const U b)
+bool test_all_bits(const T a, const U b)
 {
-  return ((a & b) == b);
+  return (a & b) == b;
 }
 
 } /* namespace drizzled */
 
-#else
-# define test(a)    ((a) ? 1 : 0)
-# define test_all_bits(a,b) (((a) & (b)) == (b))
-#endif
-
 #endif /* DRIZZLED_UTIL_TEST_H */

=== modified file 'libdrizzle/query.c'
--- libdrizzle/query.c	2010-12-12 11:52:00 +0000
+++ libdrizzle/query.c	2011-03-01 14:20:40 +0000
@@ -352,8 +352,9 @@
 {
   size_t to_size= 0;
   char newchar;
+  const char *end;
 
-  while (from_size > 0)
+  for (end= from + from_size; from < end; from++)
   {
     newchar= 0;
     /* All multi-byte UTF8 characters have the high bit set for all bytes. */
@@ -374,23 +375,28 @@
         newchar= 'Z';
         break;
       case '\\':
+        newchar= '\\';
+        break;
       case '\'':
+        newchar= '\'';
+        break;
       case '"':
-        *to++= '\\';
-        to_size++;
+        newchar= '"';
+        break;
       default:
         break;
       }
     }
-    if (newchar != 0)
+    if (newchar != '\0')
     {
       *to++= '\\';
       *to++= newchar;
       to_size++;
     }
-    else 
-      *to++= *from++;
-    from_size--;
+    else
+    { 
+      *to++= *from;
+    }
     to_size++;
   }
 

=== added file 'plugin/archive/plugin.cnf'
--- plugin/archive/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/archive/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,2 @@
+plugin-add=archive
+

=== added file 'plugin/auth_file/plugin.cnf'
--- plugin/auth_file/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/auth_file/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,2 @@
+plugin-add=auth_file
+

=== added file 'plugin/auth_http/plugin.cnf'
--- plugin/auth_http/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/auth_http/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,2 @@
+plugin-add=auth_http
+

=== added file 'plugin/auth_ldap/plugin.cnf'
--- plugin/auth_ldap/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/auth_ldap/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,2 @@
+plugin-add=auth_ldap
+

=== added file 'plugin/auth_pam/plugin.cnf'
--- plugin/auth_pam/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/auth_pam/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,2 @@
+plugin-add=auth_pam
+

=== added file 'plugin/blackhole/plugin.cnf'
--- plugin/blackhole/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/blackhole/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,2 @@
+plugin-add=blackhole
+

=== added file 'plugin/debug/plugin.cnf'
--- plugin/debug/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/debug/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,2 @@
+plugin-add=debug
+

=== added file 'plugin/filtered_replicator/plugin.cnf'
--- plugin/filtered_replicator/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/filtered_replicator/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,2 @@
+plugin-add=filtered_replicator
+

=== added file 'plugin/gearman_udf/plugin.cnf'
--- plugin/gearman_udf/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/gearman_udf/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,2 @@
+plugin-add=gearman_udf
+

=== added file 'plugin/haildb/plugin.cnf'
--- plugin/haildb/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/haildb/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,3 @@
+plugin-add=haildb
+plugin-remove=innobase
+

=== added file 'plugin/logging_gearman/plugin.cnf'
--- plugin/logging_gearman/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/logging_gearman/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,2 @@
+plugin-add=logging_gearman
+

=== added file 'plugin/logging_query/plugin.cnf'
--- plugin/logging_query/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/logging_query/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,2 @@
+plugin-add=logging_query
+

=== modified file 'plugin/myisam/sort.cc'
--- plugin/myisam/sort.cc	2010-11-06 22:20:39 +0000
+++ plugin/myisam/sort.cc	2011-03-01 18:19:16 +0000
@@ -199,8 +199,7 @@
     {
       if (!no_messages)
 	printf("  - Merging %u keys\n", (uint32_t) records);
-      if (merge_many_buff(info,keys,sort_keys,
-                  dynamic_element(&buffpek,0,BUFFPEK *),&maxbuffer,&tempfile))
+      if (merge_many_buff(info,keys,sort_keys, (BUFFPEK*)buffpek.buffer, &maxbuffer, &tempfile))
 	goto err;
     }
     if (internal::flush_io_cache(&tempfile) ||
@@ -208,8 +207,7 @@
       goto err;
     if (!no_messages)
       printf("  - Last merge and dumping keys\n");
-    if (merge_index(info,keys,sort_keys,dynamic_element(&buffpek,0,BUFFPEK *),
-                    maxbuffer,&tempfile))
+    if (merge_index(info,keys,sort_keys, (BUFFPEK*)buffpek.buffer, maxbuffer, &tempfile))
       goto err;
   }
 
@@ -400,8 +398,7 @@
       {
         if (param->testflag & T_VERBOSE)
           printf("Key %d  - Merging %u keys\n",sinfo->key+1, sinfo->keys);
-        if (merge_many_buff(sinfo, keys, (unsigned char **)mergebuf,
-			    dynamic_element(&sinfo->buffpek, 0, BUFFPEK *),
+        if (merge_many_buff(sinfo, keys, (unsigned char **)mergebuf, (BUFFPEK*)sinfo->buffpek.buffer,
 			    &maxbuffer, &sinfo->tempfile))
         {
           got_error=1;
@@ -415,8 +412,7 @@
       }
       if (param->testflag & T_VERBOSE)
         printf("Key %d  - Last merge and dumping keys\n", sinfo->key+1);
-      if (merge_index(sinfo, keys, (unsigned char **)mergebuf,
-                      dynamic_element(&sinfo->buffpek,0,BUFFPEK *),
+      if (merge_index(sinfo, keys, (unsigned char **)mergebuf, (BUFFPEK*)sinfo->buffpek.buffer,
                       maxbuffer,&sinfo->tempfile) ||
 	  flush_pending_blocks(sinfo))
       {

=== added file 'plugin/mysql_protocol/plugin.cnf'
--- plugin/mysql_protocol/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/mysql_protocol/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,9 @@
+# This configuration is disabled by default, as it potentially conflicts
+# with mysqld.  Uncomment the settings below to enable the mysql_protocol
+# plugin.
+#
+# ---
+#
+# plugin-add = mysql_protocol
+# mysql-protocol.port = 3306
+

=== added file 'plugin/pbms/plugin.cnf'
--- plugin/pbms/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/pbms/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,2 @@
+plugin-add=pbms
+

=== added file 'plugin/rabbitmq/plugin.cnf'
--- plugin/rabbitmq/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/rabbitmq/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,2 @@
+plugin-add=rabbitmq
+

=== added file 'plugin/simple_user_policy/plugin.cnf'
--- plugin/simple_user_policy/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/simple_user_policy/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,2 @@
+plugin-add=simple_user_policy
+

=== added file 'plugin/slave/plugin.cnf'
--- plugin/slave/plugin.cnf	1970-01-01 00:00:00 +0000
+++ plugin/slave/plugin.cnf	2011-03-02 02:21:20 +0000
@@ -0,0 +1,1 @@
+plugin-add=slave

=== modified file 'plugin/slave/queue_consumer.cc'
--- plugin/slave/queue_consumer.cc	2011-02-23 16:49:25 +0000
+++ plugin/slave/queue_consumer.cc	2011-03-01 20:07:54 +0000
@@ -238,6 +238,7 @@
       case message::Statement::CREATE_TABLE:
       case message::Statement::ALTER_TABLE:
       case message::Statement::DROP_TABLE:
+      case message::Statement::RAW_SQL:  /* currently ALTER TABLE or RENAME */
       {
         segmented_sql.push_back("COMMIT");
         break;

=== modified file 'plugin/transaction_log/tests/r/alter.result'
--- plugin/transaction_log/tests/r/alter.result	2011-01-18 17:30:41 +0000
+++ plugin/transaction_log/tests/r/alter.result	2011-03-01 19:35:29 +0000
@@ -19,9 +19,11 @@
 INSERT INTO `test`.`t1` (`id`,`padding`) VALUES (2,'I hate testing.');
 COMMIT;
 SET AUTOCOMMIT=0;
+USE test;
 ALTER TABLE t1 ADD dummy INT;
 COMMIT;
 SET AUTOCOMMIT=0;
+USE test;
 ALTER TABLE t1 ADD INDEX ix_padding (padding(20));
 COMMIT;
 SET AUTOCOMMIT=0;
@@ -39,9 +41,11 @@
 INSERT INTO `test`.`t1` (`id`,`padding`) VALUES (2,'I hate testing.');
 COMMIT;
 SET AUTOCOMMIT=0;
+USE test;
 ALTER TABLE t1 ADD dummy INT;
 COMMIT;
 SET AUTOCOMMIT=0;
+USE test;
 ALTER TABLE t1 ADD INDEX ix_padding (padding(20));
 COMMIT;
 SET AUTOCOMMIT=0;

=== modified file 'plugin/transaction_log/tests/r/ddl_transaction_id.result'
--- plugin/transaction_log/tests/r/ddl_transaction_id.result	2011-02-07 08:29:23 +0000
+++ plugin/transaction_log/tests/r/ddl_transaction_id.result	2011-03-01 19:35:29 +0000
@@ -204,6 +204,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 CHANGE COLUMN padding less_padding VARCHAR(180) NOT NULL"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true

=== modified file 'plugin/transaction_log/tests/r/rename.result'
--- plugin/transaction_log/tests/r/rename.result	2011-01-18 17:30:41 +0000
+++ plugin/transaction_log/tests/r/rename.result	2011-03-01 19:35:29 +0000
@@ -10,6 +10,7 @@
 CREATE TABLE `test`.`t1` (   `id` INT NOT NULL,   `padding` VARCHAR(200) COLLATE utf8_general_ci NOT NULL,   PRIMARY KEY (`id`) ) ENGINE=InnoDB COLLATE = utf8_general_ci;
 COMMIT;
 SET AUTOCOMMIT=0;
+USE test;
 RENAME TABLE t1 TO t2;
 COMMIT;
 SET AUTOCOMMIT=0;
@@ -21,6 +22,7 @@
 CREATE TABLE `test`.`t1` (   `id` INT NOT NULL,   `padding` VARCHAR(200) COLLATE utf8_general_ci NOT NULL,   PRIMARY KEY (`id`) ) ENGINE=InnoDB COLLATE = utf8_general_ci;
 COMMIT;
 SET AUTOCOMMIT=0;
+USE test;
 RENAME TABLE t1 TO t2;
 COMMIT;
 SET AUTOCOMMIT=0;

=== modified file 'plugin/transaction_log/tests/r/transaction_log_alter.result'
--- plugin/transaction_log/tests/r/transaction_log_alter.result	2011-02-07 08:29:23 +0000
+++ plugin/transaction_log/tests/r/transaction_log_alter.result	2011-03-01 19:35:29 +0000
@@ -25,6 +25,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 RENAME TO t1_new_name"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -260,6 +261,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 RENAME to t1_new_name"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -306,6 +308,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 ADD COLUMN c CHAR(100) NOT NULL"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -427,6 +430,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 ADD COLUMN c CHAR(100) NOT NULL AFTER a"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -464,6 +468,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 ADD COLUMN c CHAR(100) NOT NULL FIRST"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -501,6 +506,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 ADD COLUMN c CHAR(100) NOT NULL FIRST, ADD COLUMN d BLOB AFTER a"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -538,6 +544,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 DROP COLUMN b"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -575,6 +582,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 DROP COLUMN b, DROP COLUMN d"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -698,6 +706,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 DISABLE KEYS"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -731,6 +740,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 ENABLE KEYS"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -768,6 +778,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 ADD INDEX b_key (b,a)"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -799,6 +810,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 DROP INDEX b_key"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -836,6 +848,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 ADD INDEX b_key (b(10),a)"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -867,6 +880,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 DROP INDEX b_key"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -1085,6 +1099,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 ALTER COLUMN b SET DEFAULT 999"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -1123,6 +1138,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 ALTER COLUMN b DROP DEFAULT"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -1167,6 +1183,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 CHANGE COLUMN b new_b_name CHAR(500) DEFAULT \'I am not an int now\' FIRST"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -1211,6 +1228,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 MODIFY COLUMN b CHAR(50) DEFAULT \'I am now a CHAR field\' AFTER c"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -1355,6 +1373,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t1 MODIFY COLUMN b INT NOT NULL"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -1490,6 +1509,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t2 ADD CONSTRAINT fk_constraint_t2 FOREIGN KEY(b) REFERENCES t1(b) ON DELETE SET NULL ON UPDATE CASCADE"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true
@@ -1521,6 +1541,7 @@
   START_TIMESTAMP
   END_TIMESTAMP
   sql: "ALTER TABLE t2 DROP FOREIGN KEY fk_constraint_t2"
+  raw_sql_schema: "test"
 }
 segment_id: 1
 end_segment: true

=== modified file 'tests/dbqp.py'
--- tests/dbqp.py	2011-02-17 16:27:25 +0000
+++ tests/dbqp.py	2011-03-02 00:52:00 +0000
@@ -51,32 +51,35 @@
 execution_manager = None
 
 try:
-    # Some system-level work is constant regardless
-    # of the test to be run
-    system_manager = systemManager(variables)
-
-    # Create our server_manager
-    server_manager = serverManager(system_manager, variables)
-
-    # Get our mode-specific test_manager and test_executor
-    (test_manager,test_executor) = handle_mode(variables, system_manager)
-
-    # Gather our tests for execution
-    test_manager.gather_tests()
-
-    # Initialize test execution manager
-    execution_manager = executionManager(server_manager, system_manager
-                                    , test_manager, test_executor
-                                    , variables)
-
-    # Execute our tests!
-    execution_manager.execute_tests()
-
-except Exception, e:
-   print Exception, e
-
-except KeyboardInterrupt:
-  print "\n\nDetected <Ctrl>+c, shutting down and cleaning up..."
+    # We do this nested try to accomodate red hat
+    # running python 2.4...seriously?  2.4?
+    try:
+        # Some system-level work is constant regardless
+        # of the test to be run
+        system_manager = systemManager(variables)
+
+        # Create our server_manager
+        server_manager = serverManager(system_manager, variables)
+
+        # Get our mode-specific test_manager and test_executor
+        (test_manager,test_executor) = handle_mode(variables, system_manager)
+
+        # Gather our tests for execution
+        test_manager.gather_tests()
+
+        # Initialize test execution manager
+        execution_manager = executionManager(server_manager, system_manager
+                                        , test_manager, test_executor
+                                        , variables)
+
+        # Execute our tests!
+        execution_manager.execute_tests()
+    
+    except Exception, e:
+       print Exception, e
+
+    except KeyboardInterrupt:
+      print "\n\nDetected <Ctrl>+c, shutting down and cleaning up..."
 
 finally:
 # TODO - make a more robust cleanup

=== modified file 'unittests/libdrizzle_test.cc'
--- unittests/libdrizzle_test.cc	2011-02-17 00:14:13 +0000
+++ unittests/libdrizzle_test.cc	2011-03-01 14:20:40 +0000
@@ -39,6 +39,19 @@
   BOOST_REQUIRE_EQUAL("hello \\\"world\\\"\\n", out);
 }
 
+BOOST_AUTO_TEST_CASE(drizzleEscapeStringBinary)
+{
+  const char orig[6]= {0x00, 0x01, 0x02, 0x03, 0x04, 0x05};
+  char out[255];
+  size_t out_len;
+
+  out_len= drizzle_escape_string(out, orig, 6);
+
+  BOOST_REQUIRE_EQUAL(7, out_len);
+  BOOST_REQUIRE_EQUAL("\\0\1\2\3\4\5", out);
+}
+
+
 BOOST_AUTO_TEST_CASE(drizzleHexString)
 {
   const unsigned char orig[5]= {0x34, 0x26, 0x80, 0x99, 0xFF};

